@@ -58,6 +58,9 @@ GLADEDIR = '/usr/share/mythbuntu-control-centre/glade'
 
 ltsp_base_dir='/opt/ltsp/'
 
+#Script Directory
+SCRIPTDIR = '/usr/share/mythbuntu-common/scripts'
+
 #Translation Support
 from gettext import gettext as _
 
@@ -472,7 +475,16 @@ class Applicator():
             #self.vnc.toggle_xorg(x11vnc)
             self.vnc.toggle_xorg(False)
             if x11vnc:
-                self.vnc.create_password('"' + vnc_password + '"')
+                if not os.path.exists(os.environ["HOME"] + "/.vnc"):
+                    os.mkdir(os.environ["HOME"] + "/.vnc")
+                    os.system("chown " + os.environ["SUDO_USER"] + ":" + os.environ["SUDO_USER"] + " " + os.environ["HOME"] + "/.vnc")
+                elif os.path.exists(os.environ["HOME"] + "/.vnc/passwd"):
+                    print "Copying "+ os.environ["HOME"] + "/.vnc/passwd to "+ os.environ["HOME"] + "/.vnc/passwd.old"
+                    shutil.copy(os.environ["HOME"] + "/.vnc/passwd",os.environ["HOME"] + "/.vnc/passwd.old")
+                #Create password using expect
+                os.system(SCRIPTDIR + '/create_user_vnc_passwd "' + vnc_password + '" ' + os.environ["HOME"])
+                #let it be readale by anyone doing this
+                os.chmod(os.environ["HOME"] + "/.vnc/passwd",0664)
         else:
             self.update_gui(.375)
         if mysql_server is not None:
@@ -619,10 +631,6 @@ class Applicator():
                 home = fields[5]
                 break
         if enable:
-            #dmrc, used to define which session is autologin
-            if os.path.exists(home + '/.dmrc') and not os.path.exists(home + '/.dmrc.mythbuntu-old'):
-                shutil.move(home + '/.dmrc', home + '/.dmrc.mythbuntu-old')
-            shutil.copy('/etc/skel/.dmrc', home + '/.dmrc')
             #start myth frontend automatically
             if not os.path.exists(home + '/.config/autostart'):
                 os.makedirs(home + '/.config/autostart')
@@ -799,10 +807,10 @@ class Applicator():
 
     def update_medibuntu(self):
         #toggles medibuntu
-        medibuntuDeb = 'deb http://packages.medibuntu.org/ hardy free non-free'
+        medibuntuDeb = 'deb http://packages.medibuntu.org/ jaunty free non-free'
         #find it
         in_f=open("/etc/apt/sources.list")
-        pattern=re.compile("^deb http://packages.medibuntu.org/ hardy free non-free")
+        pattern=re.compile("^deb http://packages.medibuntu.org/ jaunty free non-free")
         medibuntu_exists=False
         for line in in_f:
             if pattern.search(line
@@ -842,10 +850,10 @@ class Applicator():
 
     def mysql_repair(self,enable_mysql_repair):
         if enable_mysql_repair == "True":
-            shutil.copy("/usr/share/doc/mythtv-backend/contrib/optimize_mythdb.pl", "/etc/cron.daily/optimize_mythdb.pl")
-            os.chmod("/etc/cron.daily/optimize_mythdb.pl",0755)
+            shutil.copy("/usr/share/doc/mythtv-backend/contrib/optimize_mythdb.pl", "/etc/cron.daily/optimize_mythdb")
+            os.chmod("/etc/cron.daily/optimize_mythdb",0755)
         elif enable_mysql_repair == "False":
-            os.remove("/etc/cron.daily/optimize_mythdb.pl")
+            os.remove("/etc/cron.daily/optimize_mythdb")
 
     def update_package_lists(self):
         lock = thread.allocate_lock()
