@@ -152,6 +152,10 @@ class ControlCentre():
                         self.user_count+=1
                 except IndexError:
                     continue 
+                #can be caused by NIS. don't support autologin here.
+                except ValueError:
+                    self.automatic_login_vbox.set_sensitive(False)
+                    break  
             #double check to see if the user 'mythtv' is in usage too.
             if os.path.exists("/etc/gdm/gdm-cdd.conf"):
                 in_f=open("/etc/gdm/gdm-cdd.conf")
@@ -866,11 +870,10 @@ class ControlCentre():
         slave_backend=self.query_installed("mythtv-backend")
         frontend=self.query_installed("mythtv-frontend")
 
-        enable_experimental_options_vbox = False
+        enable_experimental_options_vbox = True
         if master_backend or slave_backend:
             self.mythtv_setup_vbox.set_sensitive(True)
             self.mythweb_checkbox.set_sensitive(True)
-            enable_experimental_options_vbox = True
 
             if master_backend:
                 self.config.set("mythbuntu","backend","primary")
@@ -881,7 +884,9 @@ class ControlCentre():
                 self.mysql_config_vbox.set_sensitive(True)
         else:
             self.config.set("mythbuntu","backend","none")
-            enable_experimental_options_vbox = False
+            self.enable_mysql_repair.set_sensitive(False)
+            self.enable_mysql_tweaks.set_sensitive(False)
+            self.enable_ivtv_tweak.set_sensitive(False)
 
         if frontend:
             self.config.set("mythbuntu","frontend","frontend")
@@ -1313,7 +1318,7 @@ class ControlCentre():
     def find_medibuntu(self):
         """Determines if the medibuntu repo is active"""
         in_f=open("/etc/apt/sources.list")
-        pattern=re.compile("^deb http://packages.medibuntu.org/ hardy free non-free")
+        pattern=re.compile("^deb http://packages.medibuntu.org/ jaunty free non-free")
         found=False
         for line in in_f:
             if pattern.search(line):
